===============================================
2022-09-27 Dedicate Zed Release to Ilya Etingof
===============================================

The OpenStack Technical Committee and contributors to the 26th release would
like to dedicate Zed in memory of Ilya Etingof, who passed away in August.

Ilya started contributing to the Ironic project in 2017. He was the lead
contributor to the `Sushy`_ project, `Sushy Redfish emulator`_, an important
contributor to Ironic and worked tirelessly to make hardware management
reliable and consistent. His important contributions included boot management,
out-of-band hardware inspection and virtual media boot.

Outside of the OpenStack community, he has maintained Python packages with a
particular focus on SNMP. For example: `pysnmp`_, `pysmi`_, `pyasn1`_,
softboxen and many others.

Ilya was dedicated to helping younger and under-represented people. He used
to run a virtualisation technologies course at the Masaryk University in Brno
where he spoke about OpenStack and Kubernetes.

He was also an active participant in the Outreachy program where he mentored
those who contributed to Open Source projects.

 .. _`Sushy`: https://opendev.org/openstack/sushy
 .. _`Sushy Redfish emulator`: https://opendev.org/openstack/sushy-tools
 .. _`pysnmp`: https://github.com/etingof/pysnmp
 .. _`pysmi`: https://github.com/etingof/pysmi
 .. _`pyasn1`: https://github.com/etingof/pyasn1
